@@ -11,10 +11,9 @@ from tests.conftest import async_db as db, Base, User
 
 @pytest_asyncio.fixture
 async def prepare_database() -> AsyncGenerator[None, None]:
-    await db.async_run_sync(Base.metadata.create_all)
+    await db.async_run_sync(Base.metadata.create_all, is_session=False)
     yield
-    await db.async_run_sync(Base.metadata.drop_all)
-    await db.engine.dispose()
+    await db.async_run_sync(Base.metadata.drop_all, is_session=False)
 
 
 @pytest_asyncio.fixture
@@ -26,7 +25,7 @@ async def fake_users(prepare_database) -> List[dict]:
          "create_time": datetime.datetime.strptime(f"2022-01-0{i} 00:00:00", "%Y-%m-%d %H:%M:%S")
          } for i in range(1, 6)
     ]
-    await db.execute(insert(User).values(data), commit=True)
+    await db.execute(insert(User).values(data))
     return data
 
 
@@ -45,10 +44,10 @@ async def test_session_generator(fake_users):
 async def test_execute(fake_users):
     # update
     stmt = update(User).where(User.id == 1).values({'username': 'new_user'})
-    result = await db.execute(stmt, commit=True)
+    result = await db.execute(stmt)
     assert result.rowcount == 1
     # select
-    user = await db.execute(select(User).where(User.id == 1), on_close_pre=lambda r: r.scalar())
+    user = await db.execute(select(User).where(User.id == 1), commit=False, on_close_pre=lambda r: r.scalar())
     assert user.username == 'new_user'
     # insert
     stmt = insert(User).values({
@@ -56,14 +55,20 @@ async def test_execute(fake_users):
         'username': 'User-6',
         'password': 'password_6'
     })
-    result = await db.execute(stmt, commit=True)
+    result = await db.execute(stmt)
     assert result.rowcount == 1
     # delete
     stmt = delete(User).where(User.id == 6)
-    result = await db.execute(stmt, commit=True)
+    result = await db.execute(stmt)
     assert result.rowcount == 1
 
 
+async def test_execute_connection(fake_users):
+    # Select
+    user = await db.async_execute(select(User).where(User.id == 1), is_session=False, on_close_pre=lambda r: r.one())
+    assert user.id == 1
+
+
 async def test_scalar(fake_users):
     user = await db.scalar(select(User).where(User.id == 1))
     assert user.id == 1
@@ -99,6 +104,13 @@ async def test_run_sync(fake_users):
 
     user = await db.get(User, 1)
     assert user.id == 1
-    await db.run_sync(delete_user, user, is_session=True)
+    await db.run_sync(delete_user, user)
     user = await db.get(User, 1)
     assert user is None
+
+    # test on_close_pre
+    def get_user(session: Session, user_id: int):
+        return session.get(User, user_id)
+
+    user_id = await db.run_sync(get_user, 2, on_close_pre=lambda r: r.id)
+    assert user_id == 2
